import { Options } from '../types/Options';

/**
 * Retrieves default values for bot options.
 */
export declare const getDefaultBotOptions: () => {
    isOpen: boolean;
    theme: {
        primaryColor: string;
        secondaryColor: string;
        fontFamily: string;
        showHeader: boolean;
        showFooter: boolean;
        showInputRow: boolean;
        actionDisabledIcon: any;
        embedded: boolean;
        desktopEnabled: boolean;
        mobileEnabled: boolean;
    };
    tooltip: {
        mode: string;
        text: string;
    };
    chatButton: {
        icon: any;
    };
    header: {
        title: import("react/jsx-runtime").JSX.Element;
        showAvatar: boolean;
        avatar: any;
        closeChatIcon: any;
    };
    notification: {
        disabled: boolean;
        defaultToggledOn: boolean;
        volume: number;
        icon: any;
        sound: any;
    };
    audio: {
        disabled: boolean;
        defaultToggledOn: boolean;
        language: string;
        voiceNames: string[];
        rate: number;
        volume: number;
        icon: any;
    };
    chatHistory: {
        disabled: boolean;
        maxEntries: number;
        storageKey: string;
        viewChatHistoryButtonText: string;
        chatHistoryLineBreakText: string;
        autoLoad: boolean;
    };
    chatInput: {
        disabled: boolean;
        enabledPlaceholderText: string;
        disabledPlaceholderText: string;
        showCharacterCount: boolean;
        characterLimit: number;
        botDelay: number;
        sendButtonIcon: any;
        blockSpam: boolean;
        sendOptionOutput: boolean;
        sendCheckboxOutput: boolean;
        sendAttachmentOutput: boolean;
    };
    chatWindow: {
        showScrollbar: boolean;
        autoJumpToBottom: boolean;
        showMessagePrompt: boolean;
        messagePromptText: string;
        messagePromptOffset: number;
    };
    sensitiveInput: {
        maskInTextArea: boolean;
        maskInUserBubble: boolean;
        asterisksCount: number;
        hideInUserBubble: boolean;
    };
    userBubble: {
        animate: boolean;
        showAvatar: boolean;
        avatar: any;
        simStream: boolean;
        streamSpeed: number;
        dangerouslySetInnerHtml: boolean;
    };
    botBubble: {
        animate: boolean;
        showAvatar: boolean;
        avatar: any;
        simStream: boolean;
        streamSpeed: number;
        dangerouslySetInnerHtml: boolean;
    };
    voice: {
        disabled: boolean;
        defaultToggledOn: boolean;
        timeoutPeriod: number;
        autoSendDisabled: boolean;
        autoSendPeriod: number;
        icon: any;
    };
    footer: {
        text: import("react/jsx-runtime").JSX.Element;
    };
    fileAttachment: {
        disabled: boolean;
        multiple: boolean;
        accept: string;
        icon: any;
    };
    emoji: {
        disabled: boolean;
        icon: any;
        list: string[];
    };
    advance: {
        useCustomMessages: boolean;
        useCustomBotOptions: boolean;
        useCustomPaths: boolean;
    };
    tooltipStyle: {};
    chatButtonStyle: {};
    notificationBadgeStyle: {};
    chatWindowStyle: {};
    headerStyle: {};
    bodyStyle: {};
    chatInputContainerStyle: {};
    chatInputAreaStyle: {};
    chatInputAreaFocusedStyle: {};
    chatInputAreaDisabledStyle: {};
    userBubbleStyle: {};
    botBubbleStyle: {};
    botOptionStyle: {};
    botOptionHoveredStyle: {};
    botCheckboxRowStyle: {};
    botCheckboxNextStyle: {};
    botCheckMarkStyle: {};
    botCheckMarkSelectedStyle: {};
    sendButtonStyle: {};
    sendButtonHoveredStyle: {};
    characterLimitStyle: {};
    characterLimitReachedStyle: {};
    chatHistoryButtonStyle: {};
    chatHistoryButtonHoveredStyle: {};
    chatHistoryLineBreakStyle: {};
    chatMessagePromptStyle: {};
    chatMessagePromptHoveredStyle: {};
    footerStyle: {};
    loadingSpinnerStyle: {};
};
/**
 * Parses default options with user provided options to generate final bot options.
 *
 * @param providedOptions options provided by the user to the bot
 */
export declare const parseBotOptions: (providedOptions: Options | undefined) => Options | {
    isOpen: boolean;
    theme: {
        primaryColor: string;
        secondaryColor: string;
        fontFamily: string;
        showHeader: boolean;
        showFooter: boolean;
        showInputRow: boolean;
        actionDisabledIcon: any;
        embedded: boolean;
        desktopEnabled: boolean;
        mobileEnabled: boolean;
    };
    tooltip: {
        mode: string;
        text: string;
    };
    chatButton: {
        icon: any;
    };
    header: {
        title: import("react/jsx-runtime").JSX.Element;
        showAvatar: boolean;
        avatar: any;
        closeChatIcon: any;
    };
    notification: {
        disabled: boolean;
        defaultToggledOn: boolean;
        volume: number;
        icon: any;
        sound: any;
    };
    audio: {
        disabled: boolean;
        defaultToggledOn: boolean;
        language: string;
        voiceNames: string[];
        rate: number;
        volume: number;
        icon: any;
    };
    chatHistory: {
        disabled: boolean;
        maxEntries: number;
        storageKey: string;
        viewChatHistoryButtonText: string;
        chatHistoryLineBreakText: string;
        autoLoad: boolean;
    };
    chatInput: {
        disabled: boolean;
        enabledPlaceholderText: string;
        disabledPlaceholderText: string;
        showCharacterCount: boolean;
        characterLimit: number;
        botDelay: number;
        sendButtonIcon: any;
        blockSpam: boolean;
        sendOptionOutput: boolean;
        sendCheckboxOutput: boolean;
        sendAttachmentOutput: boolean;
    };
    chatWindow: {
        showScrollbar: boolean;
        autoJumpToBottom: boolean;
        showMessagePrompt: boolean;
        messagePromptText: string;
        messagePromptOffset: number;
    };
    sensitiveInput: {
        maskInTextArea: boolean;
        maskInUserBubble: boolean;
        asterisksCount: number;
        hideInUserBubble: boolean;
    };
    userBubble: {
        animate: boolean;
        showAvatar: boolean;
        avatar: any;
        simStream: boolean;
        streamSpeed: number;
        dangerouslySetInnerHtml: boolean;
    };
    botBubble: {
        animate: boolean;
        showAvatar: boolean;
        avatar: any;
        simStream: boolean;
        streamSpeed: number;
        dangerouslySetInnerHtml: boolean;
    };
    voice: {
        disabled: boolean;
        defaultToggledOn: boolean;
        timeoutPeriod: number;
        autoSendDisabled: boolean;
        autoSendPeriod: number;
        icon: any;
    };
    footer: {
        text: import("react/jsx-runtime").JSX.Element;
    };
    fileAttachment: {
        disabled: boolean;
        multiple: boolean;
        accept: string;
        icon: any;
    };
    emoji: {
        disabled: boolean;
        icon: any;
        list: string[];
    };
    advance: {
        useCustomMessages: boolean;
        useCustomBotOptions: boolean;
        useCustomPaths: boolean;
    };
    tooltipStyle: {};
    chatButtonStyle: {};
    notificationBadgeStyle: {};
    chatWindowStyle: {};
    headerStyle: {};
    bodyStyle: {};
    chatInputContainerStyle: {};
    chatInputAreaStyle: {};
    chatInputAreaFocusedStyle: {};
    chatInputAreaDisabledStyle: {};
    userBubbleStyle: {};
    botBubbleStyle: {};
    botOptionStyle: {};
    botOptionHoveredStyle: {};
    botCheckboxRowStyle: {};
    botCheckboxNextStyle: {};
    botCheckMarkStyle: {};
    botCheckMarkSelectedStyle: {};
    sendButtonStyle: {};
    sendButtonHoveredStyle: {};
    characterLimitStyle: {};
    characterLimitReachedStyle: {};
    chatHistoryButtonStyle: {};
    chatHistoryButtonHoveredStyle: {};
    chatHistoryLineBreakStyle: {};
    chatMessagePromptStyle: {};
    chatMessagePromptHoveredStyle: {};
    footerStyle: {};
    loadingSpinnerStyle: {};
};
