import { RefObject, Dispatch, SetStateAction } from 'react';
import { Options } from '../types/Options';

/**
 * Starts voice recording for input into textarea.
 *
 * @param botOptions options provided to the bot
 * @param handleToggleVoice handles toggling of voice
 * @param triggerSendVoiceInput triggers sending of voice input into chat window
 * @param setInputLength sets the input length to reflect character count & limit
 * @param inputRef reference to textarea for input
 */
export declare const startVoiceRecording: (botOptions: Options, handleToggleVoice: () => void, triggerSendVoiceInput: () => void, setInputLength: Dispatch<SetStateAction<number>>, inputRef: RefObject<HTMLTextAreaElement | HTMLInputElement>) => void;
/**
 * Stops voice recording.
 */
export declare const stopVoiceRecording: () => void;
/**
 * Syncs voice toggle to textarea state (voice should not be enabled if textarea is disabled).
 *
 * @param keepVoiceOn boolean indicating if voice was and thus is to be kept toggled on
 * @param botOptions options provided to the bot
 */
export declare const syncVoiceWithChatInput: (keepVoiceOn: boolean, botOptions: Options) => void;
